@@ -12,7 +12,7 @@ class Data(Header):
 
      Parameters
      ----------
-     data : `numpy.ndarray`, optional
+    data : `numpy.ndarray`, optional
         A 1D, 2D, or a 3D numpy array containing all the data. The elements
         of a 1D array follows the wavelength elements. A 2D array should be
         structured such that the different spectra or located along the
@@ -39,8 +39,8 @@ class Data(Header):
         Contains information for reading and writing data to and from Fits
         files.
     """
-    def __init__(self, data=None, wave=None, error=None, mask=None, error_weight=None, normalization=None, inst_fwhm=None,
-    header=None):
+    def __init__(self, data=None, wave=None, error=None, mask=None, error_weight=None, normalization=None,
+                 inst_fwhm=None, header=None):
         Header.__init__(self, header=header)
         self._data = data
         if data is not None:
